/* ============================================================================
 * File Name: DDS24_encoder
 *
 * Description:
 *   Tunable frequency and phase generator demo using 24-bit direct digital
 *   synthesis custom component DDS24.  
 *
 *   Rotary encoder is used to tune output frequency of the DDS generator between
 *   100 kHz and 300 kHz. Secondary DDS output provides synchronous reference with
 *   phase shift tunable from 0 deg to 360 deg. Pressing the button switches between
 *   frequency and phase. The Decoder is set to operate in unbounded integer mode,
 *   while all necessary calculations for frequency and phase are being performed
 *   in the main code using only direction of rotation. This provides somewhat
 *   greater flexibility in expense for extra custom code. 
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/



#include <project.h>

#define BlinkLED1(); {Pin_LED1_Write(1); CyDelayUs(130); Pin_LED1_Write(0);} // blink LED indicator

//===========================================
// Global variables
//===========================================

    #define ENCODE_FREQ  1u
    #define ENCODE_PHASE 0u 
    uint8   Encode_Type = ENCODE_FREQ;

    double Freq;            // DDS set frequency 
    uint8  Phase;           // DDS set phase 

//===========================================
// Function prototypes
//===========================================
void UpdateDDSfrequency();
void UpdateDDSphase(); 
    

void Initialize()
{   
    CyGlobalIntEnable;             //enable global interrupts.
    
    Decoder_1_Start();
    
    DDS_1_Start();                 // initialise and enable
    Freq  = DDS_1_GetFrequency();
    Phase = DDS_1_GetPhase();
}


int main()
{
    Initialize();
    
    
    for(;;) //forever
    {
        
        if (Decoder_1_PositionChanged)
        {
            //BlinkLED1();                  // debug..
            switch(Encode_Type)
            {
                case ENCODE_FREQ: {       
                    UpdateDDSfrequency();
                    break;
                };
                
                case ENCODE_PHASE: {
                    UpdateDDSphase();
                    break;
                };             
            }
        }
        
        
        if (Decoder_1_BtnPressed)
        {
            //BlinkLED1();                  // debug..
            Encode_Type = !Encode_Type;
        }

    }  
    
} // main


//==============================================================================
// Update DDS frequency
//==============================================================================

void UpdateDDSfrequency()
{
    const double step = 100.0; // Hz, frequency increment
    
    double trial = (Decoder_1_Direction>0)? Freq + step : Freq - step;
    
    // can check for min/max limits here
    
    if (DDS_1_SetFrequency(trial))  //if success
    {
        Freq = trial;
    }
}

//==============================================================================
// Update DDS phase
//==============================================================================

void UpdateDDSphase()
{
    const uint8 step = 8; // increment phase (use 2,4,8.. e.g. 256%8=0)
    Phase += (Decoder_1_Direction>0)? step : -step;  
    DDS_1_SetPhase(Phase);
}

