/* ============================================================================
 * File Name: DDS32_encoder_01
 *
 * Description:
 *   Tunable frequency generator demo using 32-bit direct digital synthesis
 *   component DDS32. 
 *
 *   Rotary encoder is used to tune output frequency of the DDS generator
 *   between 10 kHz and 20 kHz. This is achieved by setting the Decoder
 *   to operate in "double" range bounded to 1.0E+4  2.0E+4 interval.
 *   Pressing encoder button switches Decoder frequency increment step
 *   between 100 Hz and 1 Hz. Such approach results in very compact program code,
 *   performing all necessary calculations automatically inside the Decoder component.
 *   The DDS32 allows for very high precision of the output frequency (<0.01 Hz),
 *   which, in practice, is limited by the stability of the system bus clock.
 *   This can be greatly improved by using external XTAL as a clock source.
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/


#include <project.h>

#define BlinkLED1(); {Pin_LED1_Write(1); CyDelayUs(130); Pin_LED1_Write(0);} // blink LED indicator

//===========================================
// Global variables
//===========================================

uint8 enc_step_large = true;    // large step - 1000 Hz, small step - 1 Hz;

float32 step_large = 100.0;     // decoder large step 
float32 step_small = 1.0;       // decoder small step 



void Initialize()
{   
    CyGlobalIntEnable;                      // enable global interrupts.
    Decoder_1_Start();
    Decoder_1_SetIncrement(step_large);     // set step
    
    DDS_1_Start();                          // start DDS
    DDS_1_SetFrequency(Decoder_1_Position); // update frequency
}


int main()
{
    Initialize();
 
    
    for(;;) 
    {
        
        if (Decoder_1_PositionChanged)
        {
            DDS_1_SetFrequency(Decoder_1_Position); // update frequency
        }
        
        if (Decoder_1_BtnPressed)
        {
            //BlinkLED1();                  // debug..
            enc_step_large = !enc_step_large;
            
            if (enc_step_large) Decoder_1_SetIncrement(step_large); 
            else                Decoder_1_SetIncrement(step_small);   
        }
        
    }
    
} // main()



