/* ============================================================================
 * File Name: Char LCD_menu_01e
 *
 * Description:
 *   Scrollable menu example using 2x16 character LCD and single rotary encoder.
 *
 *   Cypress stock CharLCD component is used to interface LCD to PSoC. The encoder
 *   allows vertical scrolling of the menu and modifying parameters values, which
 *   can be of integer, float or enumerated range types. Pressing the button
 *   enters (exits) edit mode. 
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/


#include <project.h>
#include <LCD_menu.h>

#define BlinkLED1(); {Pin_LED1_Write(1); CyDelayUs(130); Pin_LED1_Write(0);} // blink LED indicator


//============================================
// Global variables
//============================================
const char * words [] = { "one", "two", "three" }; // define strings for _enum type


//============================================
// Forward declarations
//============================================
void SetupDecoder(uint8 editing);


void Initialize(void)
{   
    CyGlobalIntEnable; //enable global interrupts.
   
    Decoder_1_Start();
    SetupDecoder(false); // Decoder settings for menu browsing
    
    
    //setup menu->
    strcpy( Menu[0].name, "FREQ" );
    Menu[0].type=_float; //float
    Menu[0].value=1000;
    Menu[0].min=999;
    Menu[0].max=1001;
    Menu[0].step=0.1;
    Menu[0].bounds=1;
    
    strcpy( Menu[1].name, "PHSE" );
    Menu[1].type=_int;  // int
    Menu[1].value=8;
    Menu[1].min=-128;
    Menu[1].max=127;
    Menu[1].step=8;
    Menu[1].bounds=1;
    
    strcpy( Menu[2].name, "AMPL" );
    Menu[2].type=_int;  // int
    Menu[2].value=100;
    Menu[2].min=0;
    Menu[2].max=255;
    Menu[2].step=5;
    Menu[2].bounds=1;

    strcpy( Menu[3].name, "SENS" );
    Menu[3].type=_enum; // enum
    Menu[3].value=0;
    Menu[3].min=0;
    Menu[3].max=2;
    Menu[3].step=1;
    Menu[3].bounds=1;
    
    
    LCD_Start();
    LCD_LoadCustomFonts(LCD_customFonts); // cursor
    
    Refresh_LCD(false); // print menu
}


int main()
{
    
    Initialize();
    
    for(;;) 
    {
        
        if (Decoder_1_PositionChanged)
        {
            //BlinkLED1();              // debug..
            
            if (editing)                // update parameter value 
                Menu[menu_idx].value = Decoder_1_Position; // new value - take action...
            else                        // browsing top menu
                menu_idx = Decoder_1_Position;      
            
            Refresh_LCD();
        }
        
        if (Decoder_1_BtnPressed)
        {
            editing = ~editing;         //enter/exit parameter update 
            SetupDecoder(editing);
        }
        
    }


    
} //main


//==============================================================================
// Update Decoder_1 settings according to Menu current state:
// 'main menu' or 'editing a value'
//==============================================================================

void SetupDecoder( uint8 editing )
{
    if (editing) // enter parameter update
    {
        TMenuItem Item = Menu[menu_idx]; // entering menu item #menu_idx
        Decoder_1_Setup( Item.value, Item.step, Item.min, Item.max, Item.bounds );
    }    
    else         // return to top manu
        Decoder_1_Setup( menu_idx, 1, 0, MENU_LEN-1, true ); // restore Decoder settings for menu browsing
}



/// END OF PROGRAM //////////////////////////////////////////////////////////////////////////////////////

