/* ========================================
 *
 *
 *
 * ========================================
*/

    
#include <Nextion_Rx.h>


//=====================================
//  defines 
//=====================================

uint8	RxBuffer[RxBufferSize];     // Rx circular buffer to hold all incoming command
uint8  *RxReadIndex	 = RxBuffer;    // pointer to position in RxBuffer to write incoming Rx bytes
uint8  *RxWriteIndex = RxBuffer;    // pointer to position in RxBuffer to read and process bytes


//char   *RxStrIndex = RB.RxStr;      // pointer to command string buffer (processed messages)
uint8   *RxStrIndex = RB.RxStr;     // pointer to command string buffer (processed messages)
                                    // each Rx command consists of: <byte command><string value><CR>

enum {none, first_ff, second_ff} Terminator; // state machine states counting packet terminator '0xFF 0xFF 0xFF'



//==============================================================================
// using fixed function UART (P4)-> // untested
//==============================================================================
/*
CY_ISR(MyRxInt) //interrupt on Rx byte received
{   
    //UART_ClearRxInterruptSource(UART_INTR_RX_NOT_EMPTY ); //clear interrupt
    //UART_1_C _ClearRxInterruptSource(UART_INTR_RX_NOT_EMPTY ); //clear interrupt
    
    //move all available characters from Rx queue to RxBuffer
    char byte;
//    while((byte = UART_UartGetChar()) !=0 )
    while((byte = UART_1_GetChar()) !=0 )
    {
        *RxWriteIndex++ = byte; 
		if (RxWriteIndex >= RxBuffer + RxBufferSize) RxWriteIndex = RxBuffer;      
	}   

}
*/

//==============================================================================
// using UDB UART->
//==============================================================================

CY_ISR(MyRxInt) //interrupt on Rx byte received
{   
    // enable/disable isr or critical section
    
    //move all available characters from Rx queue to RxBuffer
    while(UART_1_ReadRxStatus() & UART_1_RX_STS_FIFO_NOTEMPTY)
	{
		*RxWriteIndex++ = UART_1_ReadRxData();
		if (RxWriteIndex >= RxBuffer + RxBufferSize) RxWriteIndex = RxBuffer;      
	}   
}

//==============================================================================
// 
//==============================================================================

uint8 IsCharReady(void) 
{
	return !(RxWriteIndex == RxReadIndex);
}

//==============================================================================
// Makes a single pass through circular Rx buffer one character at a time
// Returns 1 if completed message found, otherwise return value is 0
//==============================================================================

uint8 GetRxStr(void)
{
    uint8 result = 0;
    uint8 Ch;
    static uint8 Rx_cnt=0;      // received array length counter 
    
     
	Ch = *RxReadIndex++;        //read next char in buffer
    if (RxReadIndex >= RxBuffer + RxBufferSize) RxReadIndex = RxBuffer; // close circle
            
    
    if ( (Ch == EOM_FF) && (Terminator==second_ff) ) // encountered third 0xFF
    {
        *RxStrIndex++ = Ch;     // build message 
        RxStrIndex = RB.RxStr;  // reset pointer
        Terminator = none;      // reset state machine
        
        if (Rx_cnt != 3)        // non-empty message received
        {
            Rx_len = ++Rx_cnt;  // get message with terminator
            //Rx_len = Rx_cnt-2;// get message w/o terminator
            Rx_cnt = 0;         // reset counter
            result = 1;         // set flag to process message
        }   
    }
    else
    if ( (Ch == EOM_FF) && (Terminator==first_ff) ) 
    {
        Terminator=second_ff;   // encountered second 0xFF
        *RxStrIndex++ = Ch;     // build message 
        Rx_cnt++;               // increment length counter
    }
    else
    if ( (Ch == EOM_FF) && (Terminator==none) ) 
    {
        Terminator=first_ff;    // encountered first 0xFF 
        *RxStrIndex++ = Ch;     // build message 
        Rx_cnt++;               // increment length counter
    }
    else                        // body char received
    {
        Terminator=none;        // not a terminator - reset
        *RxStrIndex++ = Ch;     // build message 
        Rx_cnt++;               // increment length counter
    }   

    return result;        
}


/* [] END OF FILE */



/*
    //SCB_GetRxInterruptSource(void) & SCB_INTR_RX_NOT_EMPTY
    
    if (0u != (SCB_GetRxInterruptSourceMasked() & SCB_INTR_RX_PARITY_ERROR))
    {
        // Interrupt sources does not clear automatically if it is managed by
        // user. The interrupt sources clearing becomes user responsibility.
        
        SCB_ClearRxInterruptSource(SCB_INTR_RX_PARITY_ERROR);
    
        // Add user interrupt code to manage SCB_INTR_RX_PARITY_ERROR.
    }
*/
