/* ============================================================================
 * Project Name: encoder_poll_ex1
 *
 * Description:
 *   Example of Decoder component operating in the polling mode.
 *
 *   The Decoder component checks encoder output at 1 kHz rate and rises a flag
 *   in the main loop if position change is detected. Encoder position and
 *   direction of rotation are sent to the serial terminal window using USBUART.
 *   Pressing button switch resets encoder position.      
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/


#include <project.h>
#include <stdlib.h>
#include <stdio.h>
#include <USBUART.h>


//============================================
// Global variables
//============================================
char buff[64];//output UART buffer


//============================================
// Forward declarations
//============================================
void DisplayData(void); // output to terminal




void Initialize(void)
{   
    CyGlobalIntEnable;          //enable global interrupts.
    
    USBUART_Init();             // initialize USBUART
    
    sprintf(buff, "\n%s", "Rotary encoder example\r\n");
    USBUART_1_PutString(buff);  // Send data to terminal
    
    DisplayData();
    
    Decoder_1_Start();
}


int main()
{
    
    Initialize();
     
    
    for(;;) 
    {
            
        if (Decoder_1_PositionChanged)
        {
            DisplayData();              // output to terminal       
        }
        
        if (Decoder_1_BtnPressed)
        {
            //LED1_Write(~LED1_Read()); // debug..
            
            Decoder_1_SetPosition(0);   // some action
        }
        
    }


    
} //main



//==============================================================================
// output to terminal
//==============================================================================

void DisplayData(void) 
{ 
    
    sprintf(buff, "%d \t%d \r\n", Decoder_1_Position, Decoder_1_Direction ); // ok: int16, uint16
    
    if(USBUART_1_GetConfiguration() != 0u)      // Service USB CDC when device configured
    { 
        while(USBUART_1_CDCIsReady() == 0u);    // Wait for USB-UART is ready to send more data to the PC (no effect here)  
        USBUART_1_PutString(buff);              // Send data to PC
    }

}

/// END OF PROGRAM //////////////////////////////////////////////////////////////////////////////////////

