/* ============================================================================
 * File Name: encoder_poll_ex2
 *
 * Description:
 *   Example of multiple Decoders operating in the polling mode
 *   using INTERNAL polling interrupt (default mode).
 *
 *   The encoders are sampled at 1 kHz rate using internal interrupt, and
 *   the flag is raised if position changed. Pressing a button switch resets
 *   encoder position. USBUART is used to output position and direction of
 *   rotation to the serial terminal. 
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/

#include <project.h>
#include <stdlib.h>
#include <stdio.h>
#include <USBUART.h>


//============================================
// Global variables
//============================================
char buff[64];//output UART buffer


//============================================
// Forward declarations
//============================================
void DisplayData(void); // output to terminal




void Initialize(void)
{   
    CyGlobalIntEnable;          //enable global interrupts.
    
    USBUART_Init();             // initialize USBUART
    
    sprintf(buff, "\n%s", "Rotary encoder example\r\n");
    USBUART_1_PutString(buff);  // Send data to terminal
    
    DisplayData();
    
    Decoder_1_Start();
    Decoder_2_Start();
}


int main()
{
    
    Initialize();
     
    
    for(;;) 
    {
            
        if (Decoder_1_PositionChanged)
        {
            DisplayData();              // output to terminal       
        }
        
        if (Decoder_1_BtnPressed)
        {
            //LED1_Write(~LED1_Read()); // toggle the LED for debug..

            Decoder_1_SetPosition(0);   // some action
        }
        
        
        if (Decoder_2_PositionChanged)
        {
            DisplayData();              // output to terminal       
        }
        
        if (Decoder_2_BtnPressed)
        {
            Decoder_2_SetPosition(0);   // some action
        }
        
    }


    
} //main



//==============================================================================
// output to terminal
//==============================================================================

void DisplayData(void) 
{ 
    
    sprintf(buff, "%d \t%d \t%d \t%d \r\n", Decoder_1_Position, Decoder_1_Direction, Decoder_2_Position, Decoder_2_Direction ); // ok: int16, uint16
    
    if(USBUART_1_GetConfiguration() != 0u)      // Service USB CDC when device configured
    { 
        while(USBUART_1_CDCIsReady() == 0u);    // Wait for USB-UART is ready to send more data to the PC (no effect here)  
        USBUART_1_PutString(buff);              // Send data to PC
    }

}





/// END OF PROGRAM //////////////////////////////////////////////////////////////////////////////////////

