/* ============================================================================
 * Project Name: encoder_isr_ex1
 *
 * Description:
 *   Example of the QuadDec_SW component operating in the interrupt mode.
 *   
 *   The Decoder component reads encoder output on pin state change event using
 *   port interrupt and raises flag in the main loop if position has changed.
 *   Encoder position and direction of rotation are being output to the serial
 *   terminal window using USBUART. Pressing button switch resets the encoder position.     
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/

#include <project.h>
#include <stdlib.h>
#include <stdio.h>

#define BlinkLED(); {Pin_LED_Write(0); CyDelayUs(100); Pin_LED_Write(1);} // blink LED indicator

//============================================
// Global variables
//============================================

char buff[64];          //output UART buffer

//============================================
// Forward declarations
//============================================
void DisplayData(void); // output to terminal




void Initialize(void)
{   
    CyGlobalIntEnable;          //enable global interrupts.
    
    UART_1_Start();             // initialize USBUART
    CyDelay(250);
    
    sprintf(buff, "\n%s", "Rotary encoder example\r\n");
    UART_1_UartPutString(buff);  // Send data to terminal
    
       
    DisplayData();
    
    Decoder_1_Start();
}


int main()
{
    
    Initialize();
     
    
    for(;;) 
    {
        
        if (Decoder_1_PositionChanged)
        {
            //BlinkLED();               // debug.. 
            DisplayData();            // output to terminal    
        }
        
        if (Decoder_1_BtnPressed)
        {
            Decoder_1_SetPosition(0); // some action
        }

    }


    
} //main



//==============================================================================
// output to terminal
//==============================================================================

void DisplayData(void) 
{ 
    
    sprintf(buff, "%d \t%d \r\n", Decoder_1_Position, Decoder_1_Direction); // ok: int16, uint16
    
    UART_1_UartPutString(buff);              // Send data to PC
}



/// END OF PROGRAM //////////////////////////////////////////////////////////////////////////////////////

